==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_journal.js <==
_me = frm_journal.prototype;
function frm_journal(){};

_me.__constructor = function() {
	this._defaultSize();
	this._draw('frm_journal', 'main');
	this.maintab.tab1.X_TYPE._fillLang({
		'Conversation': "JOURNAL::CONVERSATION",
		'Document': "JOURNAL::DOCUMENT",
		'E-mail Message': "JOURNAL::E-MAIL_MESSAGE",
		'Fax': "JOURNAL::FAX",
		'Letter': "JOURNAL::LETTER",
		'Meeting': "JOURNAL::MEETING",
		'Meeting Cancellation': "JOURNAL::MEETING_CANCELLATION",
		'Meeting Request': "JOURNAL::MEETING_REQUEST",
		'Meeting Response': "JOURNAL::MEETING_RESPONSE",
		'Microsoft Office Access': "JOURNAL::MICROSOFT_OFFICE_ACCESS",
		'Microsoft Office Excel': "JOURNAL::MICROSOFT_OFFICE_EXCEL",
		'Microsoft PowerPoint': "JOURNAL::MICROSOFT_POWERPOINT",
		'Microsoft Visio': "JOURNAL::MICROSOFT_VISIO",
		'Microsoft Word': "JOURNAL::MICROSOFT_WORD",
		'Note': "JOURNAL::NOTE",
		'Phone Call': "JOURNAL::PHONE_CALL",
		'Remote Session': "JOURNAL::REMOTE_SESSION",
		'Task': "JOURNAL::TASK",
		'Task Request': "JOURNAL::TASK_REQUEST",
		'Task Response': "JOURNAL::TASK_RESPONSE"
	});
	this.maintab.tab1.X_TYPE._value('Phone Call');

	this.__initForm('JOURNAL::JOURNAL');
};

_me.__loadItems = function() {
	var me = this;
	var tab1 = this.maintab.tab1;
	loadDataIntoForm(tab1,this._aValues);

	//Copy contact name into window title
	tab1.EVNTITLE._onkeyup = function(){
		var sTitle = this._value();
		if (sTitle){
			if (sTitle.length>32)
			    sTitle = sTitle.substr(0,32)+'...';

			me._title(sTitle,true);
		}
		else
		    me._title('JOURNAL::JOURNAL');
	};
	tab1.EVNTITLE._onkeyup();
	
	if (Is.Defined(this._aValues['EVNLOCATION']) && this._aValues['EVNLOCATION'] != 'undefined') {
		var aTypeLocation = this._aValues['EVNLOCATION'].split('|');
		tab1.X_TYPE._value(aTypeLocation[0]);
		tab1.X_COMPANY._value(aTypeLocation[1]);
	}

	tab1.X_TIMEINTERVAL._value(this._aValues);
	if (!this._aValues['EVN_ID']) tab1.EVNSHARETYPE._value(GWOthers.getItem('DEFAULT_CALENDAR_SETTINGS','journal_sharing'));
	
	// TAB2 (attendees)
	this.maintab.tab2._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['CONTACTS']))
			this.X_ATTENDEES._value(me._aValues['CONTACTS']);
	}
	
	// TAB3 (attachments)
	this.maintab.tab3._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['ATTACHMENTS']))
			this.X_ATTACHMENTS._value({'path': me._sAccountID+'/'+me._sFolderID+'/'+me._sItemID, 'values': me._aValues['ATTACHMENTS']});
		else
		if (me._aValues['PUSH_ATTACHMENTS'])
			this.X_ATTACHMENTS.__addItems(me._aValues['PUSH_ATTACHMENTS']);
	}
	
	if (me._aValues['PUSH_ATTACHMENTS'])
		this.maintab.tab3._active();
};

_me.__saveItems = function(aValues) {
	aValues['values']['EVNLOCATION'] = this.maintab.tab1.X_TYPE._value() + '|' + this.maintab.tab1.X_COMPANY._value();
	aValues['values'] = arrConcat(aValues['values'], this.maintab.tab1.X_TIMEINTERVAL._value());
	
	var addon;
	if (this.maintab.tab2.X_ATTENDEES && !Is.Empty(addon = this.maintab.tab2.X_ATTENDEES._value()))
		aValues['CONTACTS'] = addon;
	if (this.maintab.tab3.X_ATTACHMENTS && !Is.Empty(addon = this.maintab.tab3.X_ATTACHMENTS._value()))
		aValues['ATTACHMENTS'] = addon;
}

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_journal.js <==
_me = frm_journal.prototype;
function frm_journal(){};

_me.__constructor = function() {
	this._defaultSize();

	var aData = {};
	var tmpf = Path.split(this._sFolderID)[0];
	if (dataSet.get('folders',[this._sAccountID,tmpf,'TYPE'])=='A')
		aData.owner = tmpf;
	else
		aData.owner = this._sAccountID;

	//this.__owner = aData.owner;

	this._draw('frm_journal', 'main', aData);
	this.maintab.tab1.X_TYPE._fillLang({
		'Conversation': "JOURNAL::CONVERSATION",
		'Document': "JOURNAL::DOCUMENT",
		'E-mail Message': "JOURNAL::E-MAIL_MESSAGE",
		'Fax': "JOURNAL::FAX",
		'Letter': "JOURNAL::LETTER",
		'Meeting': "JOURNAL::MEETING",
		'Meeting Cancellation': "JOURNAL::MEETING_CANCELLATION",
		'Meeting Request': "JOURNAL::MEETING_REQUEST",
		'Meeting Response': "JOURNAL::MEETING_RESPONSE",
		'Microsoft Office Access': "JOURNAL::MICROSOFT_OFFICE_ACCESS",
		'Microsoft Office Excel': "JOURNAL::MICROSOFT_OFFICE_EXCEL",
		'Microsoft PowerPoint': "JOURNAL::MICROSOFT_POWERPOINT",
		'Microsoft Visio': "JOURNAL::MICROSOFT_VISIO",
		'Microsoft Word': "JOURNAL::MICROSOFT_WORD",
		'Note': "JOURNAL::NOTE",
		'Phone Call': "JOURNAL::PHONE_CALL",
		'Remote Session': "JOURNAL::REMOTE_SESSION",
		'Task': "JOURNAL::TASK",
		'Task Request': "JOURNAL::TASK_REQUEST",
		'Task Response': "JOURNAL::TASK_RESPONSE"
	});
	this.maintab.tab1.X_TYPE._value('Phone Call');

	this.__initForm('JOURNAL::JOURNAL');
};

_me.__loadItems = function() {
	var me = this;
	var tab1 = this.maintab.tab1;
	loadDataIntoForm(tab1,this._aValues);

	//Copy contact name into window title
	tab1.EVNTITLE._onkeyup = function(){
		var sTitle = this._value();
		if (sTitle){
			if (sTitle.length>32)
				sTitle = sTitle.substr(0,32)+'...';

			me._title(sTitle,true);
		}
		else
			me._title('JOURNAL::JOURNAL');
	};
	tab1.EVNTITLE._onkeyup();
	
	if (Is.Defined(this._aValues['EVNLOCATION']) && this._aValues['EVNLOCATION'] != 'undefined') {
		var aTypeLocation = this._aValues['EVNLOCATION'].split('|');
		tab1.X_TYPE._value(aTypeLocation[0]);
		tab1.X_COMPANY._value(aTypeLocation[1]);
	}

	tab1.X_TIMEINTERVAL._value(this._aValues);
	if (!this._aValues['EVN_ID']) tab1.EVNSHARETYPE._value(GWOthers.getItem('DEFAULT_CALENDAR_SETTINGS','journal_sharing'));

	// TAB2 (attendees)
	this.maintab.tab2._onactive = function (bFirstTime) {
		if (bFirstTime)
			if (Is.Defined(me._aValues['CONTACTS']))
				this.X_SCHEDULE._attendees(me._aValues['CONTACTS']);

		if (me._aValues['EVNFLAGS']&1)
			this.X_SCHEDULE.X_TIMETABLE.invitation._value(1);
		else
		if (me._aValues['EVNFLAGS']&2)
			this.X_SCHEDULE.X_TIMETABLE.invitation._disabled(true);

		this.X_SCHEDULE._sync(me.maintab.tab1.X_TIMEINTERVAL);
	}

	// TAB3 (attachments)
	this.maintab.tab3._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['ATTACHMENTS']))
			this.X_ATTACHMENTS._value({'path': me._sAccountID+'/'+me._sFolderID+'/'+me._sItemID, 'values': me._aValues['ATTACHMENTS']});
		else
		if (me._aValues['PUSH_ATTACHMENTS'])
			this.X_ATTACHMENTS.__addItems(me._aValues['PUSH_ATTACHMENTS']);
	}

	if (me._aValues['PUSH_ATTACHMENTS'])
		this.maintab.tab3._active();
};

_me.__saveItems = function(aValues) {
	aValues['values']['EVNLOCATION'] = this.maintab.tab1.X_TYPE._value() + '|' + this.maintab.tab1.X_COMPANY._value();
	aValues['values'] = arrConcat(aValues['values'], this.maintab.tab1.X_TIMEINTERVAL._value());

	var addon;
	if (this.maintab.tab2.X_SCHEDULE){
		if (!Is.Empty(addon = this.maintab.tab2.X_SCHEDULE._attendees()))
			aValues['CONTACTS'] = addon;

		if (!this.maintab.tab2.X_SCHEDULE.X_TIMETABLE.invitation._disabled()){
			aValues['values'].EVNFLAGS = this.maintab.tab2.X_SCHEDULE.X_TIMETABLE.invitation._value()?1:'';
			//aValues['values'].EVNORGANIZER = this.__owner;
		}
	}

	if (this.maintab.tab3.X_ATTACHMENTS && !Is.Empty(addon = this.maintab.tab3.X_ATTACHMENTS._value()))
		aValues['ATTACHMENTS'] = addon;
}
